==> cxflow-0.8.2.tar.gz: cxflow-0.8.2/README.md <==
# cxflow
[![CircleCI](https://circleci.com/gh/Cognexa/cxflow/tree/master.svg?style=shield)](https://circleci.com/gh/Cognexa/cxflow/tree/master)
[![PyPI version](https://badge.fury.io/py/cxflow.svg)](https://badge.fury.io/py/cxflow)
[![Development Status](https://img.shields.io/badge/status-CX%20Regular-brightgreen.svg?style=flat)]()
[![MIT license](https://img.shields.io/badge/license-MIT-blue.svg?style=flat)](LICENSE)
[![Master Developer](https://img.shields.io/badge/master-Petr%20Bělohlávek-lightgrey.svg?style=flat)]()

This is an official repository of **cxflow** - a lightweight framework for machine learning with focus on modularization, re-usability and rapid experimenting.

## Installation
```
pip install cxflow
```

## Quick start

- [10 minutes tutorial](https://cxflow.org/tutorial) ([code](https://github.com/Cognexa/cxflow-examples/tree/master/majority))
- [Documentation & API Reference](https://cxflow.org/)
- [Additional examples](https://github.com/cognexa/cxflow-examples)

## Requirements
**cxflow** is supported (and tested) on [Arch Linux](https://www.archlinux.org) and [Ubuntu](http://releases.ubuntu.com) (latest LTS and rolling) with Python 3.6 and 3.5 respectively.

## Extensions
**cxflow** is meant to be extremely lightweight.
For that reason the whole functionality is divided into various extensions with separate dependencies.

At the moment we support the following extensions:

- [cxflow-tensorflow](https://github.com/Cognexa/cxflow-tensorflow) - TensorFlow support
- [cxflow-scikit](https://github.com/Cognexa/cxflow-scikit) - scientific computations and statistics
- [cxflow-rethinkdb](https://github.com/Cognexa/cxflow-rethinkdb) - RethinkDB hook for training management with NoSQL (experimental)

## Contributions

All contributions are welcomed. Please read our [contributor's guide](CONTRIBUTING.md).

## License

[MIT](LICENSE)

==> cxflow-0.10.0.tar.gz: cxflow-0.10.0/README.md <==
# cxflow
[![CircleCI](https://circleci.com/gh/Cognexa/cxflow/tree/master.svg?style=shield)](https://circleci.com/gh/Cognexa/cxflow/tree/master)
[![PyPI version](https://badge.fury.io/py/cxflow.svg)](https://badge.fury.io/py/cxflow)
[![Development Status](https://img.shields.io/badge/status-CX%20Regular-brightgreen.svg?style=flat)]()
[![MIT license](https://img.shields.io/badge/license-MIT-blue.svg?style=flat)](LICENSE)
[![Master Developer](https://img.shields.io/badge/master-Petr%20Bělohlávek-lightgrey.svg?style=flat)]()

This is an official repository of **cxflow** - a lightweight framework for machine learning with focus on modularization, re-usability and rapid experimenting.

## Installation
```
pip install cxflow
```

## Quick start

- [10 minutes tutorial](https://cxflow.org/tutorial) ([code](https://github.com/Cognexa/cxflow-examples/tree/master/majority))
- [Documentation & API Reference](https://cxflow.org/)
- [Additional examples](https://github.com/cognexa/cxflow-examples)

## Requirements
 - **cxflow** is supported (and tested) on [Arch Linux](https://www.archlinux.org) and [Ubuntu](http://releases.ubuntu.com) (latest LTS and rolling) with Python 3.6 and 3.5 respectively.
 - **cxflow** will most likely work on [Windows with Anaconda](https://www.anaconda.com/download/) and Python 3.6 yet **it is not tested regularly**


## Extensions
**cxflow** is meant to be extremely lightweight.
For that reason the whole functionality is divided into various extensions with separate dependencies.

At the moment we support the following extensions:

- [cxflow-tensorflow](https://github.com/Cognexa/cxflow-tensorflow) - TensorFlow support
- [cxflow-scikit](https://github.com/Cognexa/cxflow-scikit) - scientific computations and statistics
- [cxflow-rethinkdb](https://github.com/Cognexa/cxflow-rethinkdb) - RethinkDB hook for training management with NoSQL (experimental)

## Contributions

All contributions are welcomed. Please read our [contributor's guide](CONTRIBUTING.md).

## License

[MIT](LICENSE)
